@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1999 Erez Zadok
+ * Copyright (c) 1997-2000 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: map.c,v 1.3 1999/01/10 21:53:47 ezk Exp $
+ * $Id: map.c,v 1.6.2.1 2000/06/08 00:24:13 ezk Exp $
  *
  */
 
@@ -913,7 +913,7 @@ free_map_if_success(int rc, int term, voidp closure)
 #endif /* DEBUG */
     amd_stats.d_uerr++;
   } else if (rc) {
-    if (rc == EBUSY) {
+    if (mf->mf_ops == &amfs_program_ops || rc == EBUSY) {
       plog(XLOG_STATS, "\"%s\" on %s still active", mp->am_path, mf->mf_mount);
     } else {
       errno = rc;		/* XXX */
@@ -937,6 +937,21 @@ unmount_mp(am_node *mp)
   int was_backgrounded = 0;
   mntfs *mf = mp->am_mnt;
 
+#ifndef MNT2_NFS_OPT_SYMTTL
+    /*
+     * This code is needed to defeat Solaris 2.4's (and newer) symlink
+     * values cache.  It forces the last-modified time of the symlink to be
+     * current.  It is not needed if the O/S has an nfs flag to turn off the
+     * symlink-cache at mount time (such as Irix 5.x and 6.x). -Erez.
+     */
+  if (mp->am_parent) {
+    /* defensive programming... can't we assert the above condition? */
+    nfsattrstat *attrp = &mp->am_parent->am_attr;
+    if (++attrp->ns_u.ns_attr_u.na_mtime.nt_useconds == 0)
+      ++attrp->ns_u.ns_attr_u.na_mtime.nt_seconds;
+  }
+#endif /* not MNT2_NFS_OPT_SYMTTL */
+
 #ifdef notdef
   plog(XLOG_INFO, "\"%s\" on %s timed out", mp->am_path, mp->am_mnt->mf_mount);
 #endif /* notdef */
